<?php
/**
 * magpoint Theme Customizer
 *
 * @package magpoint
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */


function magpoint_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'magpoint_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'magpoint_customize_partial_blogdescription',
			)
		);
	}

	/*Magpoint Option Panel*/
	$wp_customize->add_panel( 'magpoint_theme_options', array(
	    'title'     => __( 'Magpoint Theme Options', 'magpoint' ),
	    'priority'  => 1,
	) );

	/*Top Header Options Section*/
	$wp_customize->add_section( 'magpoint_top_header_options', array (
		'title'     => __( 'Top Header Options', 'magpoint' ),
		'panel'     => 'magpoint_theme_options',
		'priority'  => 10,
		'description' => __( 'Personalize the settings top header.', 'magpoint' ),
	) );

	// Top Header Display Control
	$wp_customize->add_setting ( 'magpoint_top_header_display', array (
		'default'           =>  false,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_display', array (
		'label'           => __( 'Display Top Header', 'magpoint' ),
		'section'         => 'magpoint_top_header_options',
		'priority'        => 1,
		'type'            => 'checkbox',
	) );

	// Top Header Contact Display Control
	$wp_customize->add_setting ( 'magpoint_top_header_contact_display', array (
		'default'           => false,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_contact_display', array (
		'label'           => __( 'Display Contact Number', 'magpoint' ),
		'section'         => 'magpoint_top_header_options',
		'priority'        => 2,
		'type'            => 'checkbox',
		'active_callback' => 'magpoint_header_active_callback'
	) );

	// Contact Number
	$wp_customize->add_setting ( 'magpoint_top_header_contact', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_contact', array(
		'label'    => __( 'Contact Number', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 3,
		'type'     => 'text',
		'active_callback' => 'magpoint_header_contact_active_callback'
	) );

  // Top Header Email Display Control
	$wp_customize->add_setting ( 'magpoint_top_header_email_display', array (
		'default'           => false,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_email_display', array (
		'label'           => __( 'Display Email', 'magpoint' ),
		'section'         => 'magpoint_top_header_options',
		'priority'        => 4,
		'type'            => 'checkbox',
		'active_callback' => 'magpoint_header_active_callback'
	) );

	// Email
	$wp_customize->add_setting ( 'magpoint_top_header_email', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_email', array(
		'label'    => __( 'Email', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 5,
		'type'     => 'text',
		'active_callback' => 'magpoint_header_email_active_callback'
	) );

	// Top Header Address Display Control
	$wp_customize->add_setting ( 'magpoint_top_header_address_display', array (
		'default'           => false,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_address_display', array (
		'label'           => __( 'Display Address', 'magpoint' ),
		'section'         => 'magpoint_top_header_options',
		'priority'        => 6,
		'type'            => 'checkbox',
		'active_callback' => 'magpoint_header_active_callback'
	) );

	// Address
	$wp_customize->add_setting ( 'magpoint_top_header_address', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_address', array(
		'label'    => __( 'Address', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 7,
		'type'     => 'text',
		'active_callback' => 'magpoint_header_address_active_callback'
	) );

	// Top Header Menu Social Icon Display Control
	$wp_customize->add_setting ( 'magpoint_top_header_social_icon_display', array (
		'default'           => false,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_top_header_social_icon_display', array (
		'label'           => __( 'Display Top Header Social Icons', 'magpoint' ),
		'section'         => 'magpoint_top_header_options',
		'priority'        => 8,
		'type'            => 'checkbox',
		'active_callback' => 'magpoint_header_active_callback'
	) );

	// Facebook URL
	$wp_customize->add_setting ( 'magpoint_social_icon_fb_url', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'esc_url_raw',


	) );

	$wp_customize->add_control ( 'magpoint_social_icon_fb_url', array(
		'label'    => __( 'Facebook URL', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 9,
		'type'     => 'url',
		'active_callback' => 'magpoint_header_social_active_callback'

	) );

	// Twitter URL
	$wp_customize->add_setting ( 'magpoint_social_icon_twitter_url', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control ( 'magpoint_social_icon_twitter_url', array(
		'label'    => __( 'Twitter URL', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 10,
		'type'     => 'url',
		'active_callback' => 'magpoint_header_social_active_callback'
	) );

	// Linkedin URL
	$wp_customize->add_setting ( 'magpoint_social_icon_linkedin_url', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control ( 'magpoint_social_icon_linkedin_url', array(
		'label'    => __( 'Linkedin URL', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 11,
		'type'     => 'url',
		'active_callback' => 'magpoint_header_social_active_callback'
	) );

	// Instagram URL
	$wp_customize->add_setting ( 'magpoint_social_icon_insta_url', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control ( 'magpoint_social_icon_insta_url', array(
		'label'    => __( 'Instagram URL', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 12,
		'type'     => 'url',
		'active_callback' => 'magpoint_header_social_active_callback'
	) );

	// Pinterest URL
	$wp_customize->add_setting ( 'magpoint_social_icon_pint_url', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control ( 'magpoint_social_icon_pint_url', array(
		'label'    => __( 'Pinterest URL', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 13,
		'type'     => 'url',
		'active_callback' => 'magpoint_header_social_active_callback'
	) );

		// Youtube URL
	$wp_customize->add_setting ( 'magpoint_social_icon_yout_url', array(
		'default'           => __( '', 'magpoint' ),
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control ( 'magpoint_social_icon_yout_url', array(
		'label'    => __( 'Youtube URL', 'magpoint' ),
		'section'  => 'magpoint_top_header_options',
		'priority' => 14,
		'type'     => 'url',
		'active_callback' => 'magpoint_header_social_active_callback'
	) );

	// Social URL Target Display Control
	$wp_customize->add_setting ( 'magpoint_social_icon_target_display', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_social_icon_target_display', array (
		'label'           => __( 'Display Social URL in new Window', 'magpoint' ),
		'section'         => 'magpoint_top_header_options',
		'priority'        => 15,
		'type'            => 'checkbox',
		'active_callback' => 'magpoint_header_social_active_callback'
	) );


	/*General Options Section*/
	$wp_customize->add_section( 'magpoint_general_options', array (
		'title'     => __( 'General Options', 'magpoint' ),
		'panel'     => 'magpoint_theme_options',
		'priority'  => 20,
		'description' => __( 'Personalize the settings of your theme.', 'magpoint' ),
	) );

	// Read More Label
	$wp_customize->add_setting ( 'magpoint_read_more_label', array(
		'default'           => __( 'Read More', 'magpoint' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control ( 'magpoint_read_more_label', array(
		'label'    => __( 'Read More Label', 'magpoint' ),
		'section'  => 'magpoint_general_options',
		'priority' => 1,
		'type'     => 'text',
	) );

	// Excerpt Length
	$wp_customize->add_setting ( 'magpoint_excerpt_length', array(
		'default'           => __( '55', 'magpoint' ),
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control ( 'magpoint_excerpt_length', array(
		'label'    => __( 'Excerpt Length', 'magpoint' ),
		'description' => __( '0 length will not show the excerpt.', 'magpoint' ),
		'section'  => 'magpoint_general_options',
		'priority' => 2,
		'type'     => 'number',
	) );

	/*layout options*/
	$wp_customize->add_section( 'magpoint_layout_options', array (
		'title'     => __( 'Layout Options', 'magpoint' ),
		'panel'     => 'magpoint_theme_options',
		'priority'  => 30,
		'description' => __( 'Personalize the layout settings of your theme.', 'magpoint' ),
	) );

	// Theme Layout
	$wp_customize->add_setting ( 'magpoint_theme_layout', array(
		'default'           => __('wide', 'magpoint' ),
		'sanitize_callback' => 'magpoint_sanitize_select',
	) );

	$wp_customize->add_control ( 'magpoint_theme_layout', array(
		'label'    => __( 'Theme Layout', 'magpoint' ),
		'description' => __( 'Box layout will be visible at minimum 1200px display', 'magpoint' ),
		'section'  => 'magpoint_layout_options',
		'priority' => 1,
		'type'     => 'select',
		'choices'  => array(
			'wide' => __( 'Wide', 'magpoint' ),
			'box'  => __( 'Box',  'magpoint' ),
		),
	) );

	// Main Sidebar Position
	$wp_customize->add_setting ( 'magpoint_sidebar_position', array (
		'default'           => __( 'right', 'magpoint' ),
		'sanitize_callback' => 'magpoint_sanitize_select',
	) );

	$wp_customize->add_control ( 'magpoint_sidebar_position', array (
		'label'    => __( 'Sidebar Position', 'magpoint' ),
		'section'  => 'magpoint_layout_options',
		'priority' => 2,
		'type'     => 'select',
		'choices'  => array(
			'right' => __( 'Right Sidebar', 'magpoint'),
			'left'  => __( 'Left Sidebar',  'magpoint'),
			'no'    => __( 'No Sidebar',  'magpoint'),
		),
	) );

	/*Blog Post Options*/
	$wp_customize->add_section( 'magpoint_archive_content_options', array (
		'title'     => __( 'Blog Post Options', 'magpoint' ),
		'panel'     => 'magpoint_theme_options',
		'priority'  => 40,
		'description' => __( 'Setting will also apply on archieve and search page.', 'magpoint' ),
	) );

	// Post Author Display Control
	$wp_customize->add_setting ( 'magpoint_archive_co_post_author', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_archive_co_post_author', array (
		'label'           => __( 'Display Author', 'magpoint' ),
		'section'         => 'magpoint_archive_content_options',
		'priority'        => 2,
		'type'            => 'checkbox',
	) );

	// Post Comments Display Control
	$wp_customize->add_setting ( 'magpoint_archive_co_post_comments', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_archive_co_post_comments', array (
		'label'           => __( 'Display Comments Count', 'magpoint' ),
		'section'         => 'magpoint_archive_content_options',
		'priority'        => 3,
		'type'            => 'checkbox',
	) );

	// Post Date Display Control
	$wp_customize->add_setting ( 'magpoint_archive_co_post_date', array (
		'default'           =>  true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_archive_co_post_date', array (
		'label'           => __( 'Display Date', 'magpoint' ),
		'section'         => 'magpoint_archive_content_options',
		'priority'        => 4,
		'type'            => 'checkbox',
	) );

	// Featured Image Archive Control
	$wp_customize->add_setting ( 'magpoint_archive_co_featured_image', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_archive_co_featured_image', array (
		'label'           => __( 'Display Featured Image', 'magpoint' ),
		'section'         => 'magpoint_archive_content_options',
		'priority'        => 5,
		'type'            => 'checkbox',
	) );

	/*Single Post Options*/
	$wp_customize->add_section( 'magpoint_single_content_options', array (
		'title'     => __( 'Single Post Options', 'magpoint' ),
		'panel'     => 'magpoint_theme_options',
		'priority'  => 50,
		'description' => __( 'Setting will apply on the content of single posts.', 'magpoint' ),
	) );

	// Post Categories Display Control
	$wp_customize->add_setting ( 'magpoint_single_co_post_categories', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_single_co_post_categories', array (
		'label'           => __( 'Display Categories', 'magpoint' ),
		'section'         => 'magpoint_single_content_options',
		'priority'        => 1,
		'type'            => 'checkbox',
	) );

	// Post Author Display Control
	$wp_customize->add_setting ( 'magpoint_single_co_post_author', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_single_co_post_author', array (
		'label'           => __( 'Display Author', 'magpoint' ),
		'section'         => 'magpoint_single_content_options',
		'priority'        => 2,
		'type'            => 'checkbox',
	) );

	// Single Post Comments Display Control
	$wp_customize->add_setting ( 'magpoint_single_co_post_comments', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_single_co_post_comments', array (
		'label'           => __( 'Display Comments Count', 'magpoint' ),
		'section'         => 'magpoint_single_content_options',
		'priority'        => 3,
		'type'            => 'checkbox',
	) );

	// Post Date Display Control
	$wp_customize->add_setting ( 'magpoint_single_co_post_date', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_single_co_post_date', array (
		'label'           => __( 'Display Date', 'magpoint' ),
		'section'         => 'magpoint_single_content_options',
		'priority'        => 4,
		'type'            => 'checkbox',
	) );

	// Single Post Tags Display Control
	$wp_customize->add_setting ( 'magpoint_single_co_post_tags', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_single_co_post_tags', array (
		'label'           => __( 'Display Tags', 'magpoint' ),
		'section'         => 'magpoint_single_content_options',
		'priority'        => 5,
		'type'            => 'checkbox',
	) );

	// Featured Image Post Display Control
	$wp_customize->add_setting ( 'magpoint_single_co_featured_image_post', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_single_co_featured_image_post', array (
		'label'           => __( 'Display Featured Image', 'magpoint' ),
		'section'         => 'magpoint_single_content_options',
		'priority'        => 7,
		'type'            => 'checkbox',
	) );

	/*Footer Option*/
	$wp_customize->add_section( 'magpoint_footer_options', array (
		'title'       => __( 'Footer Options', 'magpoint' ),
		'panel'       => 'magpoint_theme_options',
		'priority'    => 60,
		'description' => __( 'Personalize the footer settings of your theme.', 'magpoint' ),
	) );

	// Top Header Display Control
	$wp_customize->add_setting ( 'magpoint_footer_copyright_display', array (
		'default'           => true,
		'sanitize_callback' => 'magpoint_sanitize_checkbox',
	) );

	$wp_customize->add_control ( 'magpoint_footer_copyright_display', array (
		'label'           => __( 'Display Copyright Footer', 'magpoint' ),
		'section'         => 'magpoint_footer_options',
		'priority'        => 1,
		'type'            => 'checkbox',
	) );

	// Copyright Control
	$wp_customize->add_setting ( 'magpoint_copyright', array (
		'default'           => __( 'Powered by WordPress', 'magpoint' ),
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control ( 'magpoint_copyright', array (
		'label'    => __( 'Copyright', 'magpoint' ),
		'section'  => 'magpoint_footer_options',
		'priority' => 2,
		'type'     => 'textarea',
		'active_callback' => 'magpoint_footer_copyright_callback'
	) );
}
add_action( 'customize_register', 'magpoint_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function magpoint_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function magpoint_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function magpoint_customize_preview_js() {
	wp_enqueue_script( 'magpoint-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), MAGPOINT_VERSION, true );
}
add_action( 'customize_preview_init', 'magpoint_customize_preview_js' );

/*callback function for top header section*/
if ( !function_exists('magpoint_header_active_callback') ) :
  function magpoint_header_active_callback(){
  	  $show_topheader = get_theme_mod('magpoint_top_header_display',true);
      
      if( true == $show_topheader ){
          return true;
      }
      else{
          return false;
      }
  }
endif;
if ( !function_exists('magpoint_header_social_active_callback') ) :
  function magpoint_header_social_active_callback(){
  	  $show_social = get_theme_mod('magpoint_top_header_social_icon_display',true);
  	  $show_topheader = get_theme_mod('magpoint_top_header_display',true);
      
      if( $show_social && $show_topheader ){
          return true;
      }
      else{
          return false;
      }
  }
endif;


if ( !function_exists('magpoint_header_contact_active_callback') ) :
  function magpoint_header_contact_active_callback(){
  	  $show_contact = get_theme_mod('magpoint_top_header_contact_display',true);
  	  $show_topheader = get_theme_mod('magpoint_top_header_display',true);
      
      if( $show_contact && $show_topheader ){
          return true;
      }
      else{
          return false;
      }
  }
endif;


if ( !function_exists('magpoint_header_email_active_callback') ) :
  function magpoint_header_email_active_callback(){
  	  $show_email = get_theme_mod('magpoint_top_header_email_display',true);
  	  $show_topheader = get_theme_mod('magpoint_top_header_display',true);
      
      if( $show_email && $show_topheader ){
          return true;
      }
      else{
          return false;
      }
  }
endif;


if ( !function_exists('magpoint_header_address_active_callback') ) :
  function magpoint_header_address_active_callback(){
  	  $show_address = get_theme_mod('magpoint_top_header_address_display',true);
  	  $show_topheader = get_theme_mod('magpoint_top_header_display',true);
      
      if( $show_address && $show_topheader ){
          return true;
      }
      else{
          return false;
      }
  }
endif;

if ( !function_exists('magpoint_footer_copyright_callback') ) :
  function magpoint_footer_copyright_callback(){
  
  	  $show_copyright = get_theme_mod('magpoint_footer_copyright_display',true);
      
      if( true == $show_copyright ){
          return true;
      }
      else{
          return false;
      }
  }
endif;